aboutsummaryrefslogtreecommitdiff
path: root/tests/fixtures
diff options
context:
space:
mode:
authorGravatar Alexandre Alapetite <alexandre@alapetite.fr> 2023-04-17 08:30:21 +0200
committerGravatar GitHub <noreply@github.com> 2023-04-17 08:30:21 +0200
commitf3760f138dcbaf7a2190336a0378cf1b2190c9f5 (patch)
tree6fac8fbf9efd7aa74a8e3970ab70ccf85287b2cd /tests/fixtures
parent41fa4e746df8c2e2399ed753b4994ca85cb21358 (diff)
Complete PHPStan Level 6 (#5305)
* Complete PHPStan Level 6 Fix https://github.com/FreshRSS/FreshRSS/issues/4112 And initiate PHPStan Level 7 * PHPStan Level 6 for tests * Use phpstan/phpstan-phpunit * Update to PHPStan version 1.10 * Fix mixed bug * Fix mixed return bug * Fix paginator bug * Fix FreshRSS_UserConfiguration * A couple more Minz_Configuration bug fixes * A few trivial PHPStan Level 7 fixes * A few more simple PHPStan Level 7 * More files passing PHPStan Level 7 Add interface to replace removed class from https://github.com/FreshRSS/FreshRSS/pull/5251 * A few more PHPStan Level 7 preparations * A few last details
Diffstat (limited to 'tests/fixtures')
-rw-r--r--tests/fixtures/migrations/2019_12_22_FooBar.php4
-rw-r--r--tests/fixtures/migrations/2019_12_23_Baz.php4
-rw-r--r--tests/fixtures/migrations_with_failing/2020_01_11_FooBar.php4
-rw-r--r--tests/fixtures/migrations_with_failing/2020_01_12_Baz.php4
4 files changed, 8 insertions, 8 deletions
diff --git a/tests/fixtures/migrations/2019_12_22_FooBar.php b/tests/fixtures/migrations/2019_12_22_FooBar.php
index 4568ea8c9..21f673213 100644
--- a/tests/fixtures/migrations/2019_12_22_FooBar.php
+++ b/tests/fixtures/migrations/2019_12_22_FooBar.php
@@ -2,9 +2,9 @@
class FreshRSS_Migration_2019_12_22_FooBar {
/**
* @return boolean true if the migration was successful, false otherwise
*/
- public static function migrate() {
+ public static function migrate(): bool {
return true;
}
}
@@ -2,9 +2,9 @@
class FreshRSS_Migration_2019_12_22_FooBar {
/**
- * @return boolean true if the migration was successful, false otherwise
+ * @return bool true if the migration was successful, false otherwise
*/
diff --git a/tests/fixtures/migrations/2019_12_23_Baz.php b/tests/fixtures/migrations/2019_12_23_Baz.php
index c13b2a814..056b0836c 100644
--- a/tests/fixtures/migrations/2019_12_23_Baz.php
+++ b/tests/fixtures/migrations/2019_12_23_Baz.php
@@ -2,9 +2,9 @@
class FreshRSS_Migration_2019_12_23_Baz {
/**
* @return boolean true if the migration was successful, false otherwise
*/
- public static function migrate() {
+ public static function migrate(): bool {
return true;
}
}
@@ -2,9 +2,9 @@
class FreshRSS_Migration_2019_12_23_Baz {
/**
- * @return boolean true if the migration was successful, false otherwise
+ * @return bool true if the migration was successful, false otherwise
*/
diff --git a/tests/fixtures/migrations_with_failing/2020_01_11_FooBar.php b/tests/fixtures/migrations_with_failing/2020_01_11_FooBar.php
index cdc2dd2c8..2edc79964 100644
--- a/tests/fixtures/migrations_with_failing/2020_01_11_FooBar.php
+++ b/tests/fixtures/migrations_with_failing/2020_01_11_FooBar.php
@@ -2,9 +2,9 @@
class FreshRSS_Migration_2020_01_11_FooBar {
/**
* @return boolean true if the migration was successful, false otherwise
*/
- public static function migrate() {
+ public static function migrate(): bool {
return true;
}
}
@@ -2,9 +2,9 @@
class FreshRSS_Migration_2020_01_11_FooBar {
/**
- * @return boolean true if the migration was successful, false otherwise
+ * @return bool true if the migration was successful, false otherwise
*/
diff --git a/tests/fixtures/migrations_with_failing/2020_01_12_Baz.php b/tests/fixtures/migrations_with_failing/2020_01_12_Baz.php
index cd8ff10f3..75f39f7b5 100644
--- a/tests/fixtures/migrations_with_failing/2020_01_12_Baz.php
+++ b/tests/fixtures/migrations_with_failing/2020_01_12_Baz.php
@@ -2,9 +2,9 @@
class FreshRSS_Migration_2020_01_12_Baz {
/**
* @return boolean true if the migration was successful, false otherwise
*/
- public static function migrate() {
+ public static function migrate(): bool {
return false;
}
}
@@ -2,9 +2,9 @@
class FreshRSS_Migration_2020_01_12_Baz {
/**
- * @return boolean true if the migration was successful, false otherwise
+ * @return bool true if the migration was successful, false otherwise
*/